@@ -24,14 +24,13 @@
 // Qt
 #include <QtGui/QColor>
 #include <QtCore/QPointer>
-#include <QWidget>
+#include <QtGui/QWidget>
 
 // Konsole
 #include "Character.h"
 #include "konsole_export.h"
 #include "ScreenWindow.h"
 #include "ColorScheme.h"
-#include "Enumeration.h"
 
 class QDrag;
 class QDragEnterEvent;
@@ -45,12 +44,17 @@ class QScrollBar;
 class QShowEvent;
 class QHideEvent;
 class QTimerEvent;
+class QWidget;
+
+class KMenu;
 
 namespace Konsole
 {
+
 class FilterChain;
 class TerminalImageFilterChain;
 class SessionController;
+
 /**
  * A widget which displays output from a terminal emulation and sends input keypresses and mouse activity
  * to the terminal.
@@ -62,11 +66,11 @@ class SessionController;
  */
 class KONSOLEPRIVATE_EXPORT TerminalDisplay : public QWidget
 {
-    Q_OBJECT
+   Q_OBJECT
 
 public:
     /** Constructs a new terminal display widget with the specified parent. */
-    explicit TerminalDisplay(QWidget* parent = 0);
+    TerminalDisplay(QWidget* parent=0);
     virtual ~TerminalDisplay();
 
     /** Returns the terminal color palette used by the display. */
@@ -90,14 +94,23 @@ public:
     /** Sets the background picture */
     void setWallpaper(ColorSchemeWallpaper::Ptr p);
 
+    /**
+     * This enum describes the location where the scroll bar is positioned in the display widget.
+     */
+    enum ScrollBarPosition
+    {
+        /** Show the scroll bar on the left side of the display. */
+        ScrollBarLeft = 0,
+        /** Show the scroll bar on the right side of the display. */
+        ScrollBarRight = 1,
+        /** Do not show the scroll bar. */
+        ScrollBarHidden = 2
+    };
     /**
      * Specifies whether the terminal display has a vertical scroll bar, and if so whether it
      * is shown on the left or right side of the display.
      */
-    void setScrollBarPosition(Enum::ScrollBarPositionEnum position);
-    Enum::ScrollBarPositionEnum scrollBarPosition() const {
-        return _scrollbarLocation;
-    }
+    void setScrollBarPosition(ScrollBarPosition position);
 
     /**
      * Sets the current position and range of the display's scroll bar.
@@ -107,9 +120,6 @@ public:
      */
     void setScroll(int cursor, int lines);
 
-    void setScrollFullPage(bool fullPage);
-    bool scrollFullPage() const;
-
     /**
      * Returns the display's filter chain.  When the image for the display is updated,
      * the text is passed through each filter in the chain.  Each filter can define
@@ -148,79 +158,65 @@ public:
     /** Specifies whether or not the cursor can blink. */
     void setBlinkingCursorEnabled(bool blink);
     /** Returns true if the cursor is allowed to blink or false otherwise. */
-    bool blinkingCursorEnabled() const {
-        return _allowBlinkingCursor;
-    }
+    bool blinkingCursorEnabled() const { return _allowBlinkingCursor; }
 
     /** Specifies whether or not text can blink. */
     void setBlinkingTextEnabled(bool blink);
 
-    void setControlDrag(bool enable) {
-        _ctrlRequiredForDrag = enable;
-    }
-    bool ctrlRequiredForDrag() const {
-        return _ctrlRequiredForDrag;
-    }
+    void setCtrlDrag(bool enable) { _ctrlDrag=enable; }
+    bool ctrlDrag() const { return _ctrlDrag; }
 
+    /**
+     *  This enum describes the methods for selecting text when
+      *  the user triple-clicks within the display.
+      */
+    enum TripleClickMode
+    {
+        /** Select the whole line underneath the cursor. */
+        SelectWholeLine,
+        /** Select from the current cursor position to the end of the line. */
+        SelectForwardsFromCursor
+    };
     /** Sets how the text is selected when the user triple clicks within the display. */
-    void setTripleClickMode(Enum::TripleClickModeEnum mode) {
-        _tripleClickMode = mode;
-    }
+    void setTripleClickMode(TripleClickMode mode) { _tripleClickMode = mode; }
     /** See setTripleClickSelectionMode() */
-    Enum::TripleClickModeEnum tripleClickMode() const {
-        return _tripleClickMode;
-    }
+    TripleClickMode tripleClickMode() const { return _tripleClickMode; }
 
     /**
      * Specifies whether links and email addresses should be underlined when
      * hovered by the mouse. Defaults to true.
      */
-    void setUnderlineLinks(bool value) {
-        _underlineLinks = value;
-    }
+    void setUnderlineLinks(bool value) { _underlineLinks = value; }
     /**
      * Returns true if links and email addresses should be underlined when
      * hovered by the mouse.
      */
-    bool getUnderlineLinks() const {
-        return _underlineLinks;
-    }
-
-    /**
-     * Specifies whether links and email addresses should be opened when
-     * clicked with the mouse. Defaults to false.
-     */
-    void setOpenLinksByDirectClick(bool value) {
-        _openLinksByDirectClick = value;
-    }
-    /**
-     * Returns true if links and email addresses should be opened when
-     * clicked with the mouse.
-     */
-    bool getOpenLinksByDirectClick() const {
-        return _openLinksByDirectClick;
-    }
-
-    /**
-     * Sets whether trailing spaces should be trimmed in selected text.
-     */
-    void setTrimTrailingSpaces(bool enabled) {
-        _trimTrailingSpaces = enabled;
-    }
-
-    /**
-     * Returns true if trailing spaces should be trimmed in selected text.
-     */
-    bool trimTrailingSpaces() const {
-        return _trimTrailingSpaces;
-    }
+    bool getUnderlineLinks() const { return _underlineLinks; }
 
     void setLineSpacing(uint);
     uint lineSpacing() const;
 
     void setSessionController(SessionController* controller);
-    SessionController* sessionController();
 
+    /**
+     * This enum describes the available shapes for the keyboard cursor.
+     * See setKeyboardCursorShape()
+     */
+    enum KeyboardCursorShape
+    {
+        /** A rectangular block which covers the entire area of the cursor character. */
+        BlockCursor,
+        /**
+         * A single flat line which occupies the space at the bottom of the cursor
+         * character's area.
+         */
+        UnderlineCursor,
+        /**
+         * An cursor shaped like the capital letter 'I', similar to the IBeam
+         * cursor used in Qt/KDE text editors.
+         */
+        IBeamCursor
+    };
     /**
      * Sets the shape of the keyboard cursor.  This is the cursor drawn
      * at the position in the terminal where keyboard input will appear.
@@ -231,11 +227,11 @@ public:
      *
      * Defaults to BlockCursor
      */
-    void setKeyboardCursorShape(Enum::CursorShapeEnum shape);
+    void setKeyboardCursorShape(KeyboardCursorShape shape);
     /**
      * Returns the shape of the keyboard cursor.  See setKeyboardCursorShape()
      */
-    Enum::CursorShapeEnum keyboardCursorShape() const;
+    KeyboardCursorShape keyboardCursorShape() const;
 
     /**
      * Sets the color used to draw the keyboard cursor.
@@ -243,14 +239,14 @@ public:
      * The keyboard cursor defaults to using the foreground color of the character
      * underneath it.
      *
-     * @param color By default, the widget uses the color of the
-     * character under the cursor to draw the cursor, and inverts the
-     * color of that character to make sure it is still readable. If @p
-     * color is a valid QColor, the widget uses that color to draw the
-     * cursor. If @p color is not an valid QColor, the widget falls back
-     * to the default behavior.
+     * @param useForegroundColor If true, the cursor color will change to match
+     * the foreground color of the character underneath it as it is moved, in this
+     * case, the @p color parameter is ignored and the color of the character
+     * under the cursor is inverted to ensure that it is still readable.
+     * @param color The color to use to draw the cursor.  This is only taken into
+     * account if @p useForegroundColor is false.
      */
-    void setKeyboardCursorColor(const QColor& color);
+    void setKeyboardCursorColor(bool useForegroundColor , const QColor& color);
 
     /**
      * Returns the color of the keyboard cursor, or an invalid color if the keyboard
@@ -265,9 +261,7 @@ public:
      * This will depend upon the height of the widget and the current font.
      * See fontHeight()
      */
-    int  lines() const {
-        return _lines;
-    }
+    int  lines() const { return _lines; }
     /**
      * Returns the number of characters of text which can be displayed on
      * each line in the widget.
@@ -275,25 +269,20 @@ public:
      * This will depend upon the width of the widget and the current font.
      * See fontWidth()
      */
-    int  columns() const {
-        return _columns;
-    }
+    int  columns() const { return _columns; }
 
     /**
      * Returns the height of the characters in the font used to draw the text in the display.
      */
-    int  fontHeight() const {
-        return _fontHeight;
-    }
+    int  fontHeight() const { return _fontHeight; }
     /**
      * Returns the width of the characters in the display.
      * This assumes the use of a fixed-width font.
      */
-    int  fontWidth() const {
-        return _fontWidth;
-    }
+    int  fontWidth() const { return _fontWidth; }
 
     void setSize(int columns, int lines);
+    void setFixedSize(int columns, int lines);
 
     // reimplemented
     QSize sizeHint() const;
@@ -316,9 +305,7 @@ public:
      *
      * @see setWordCharacters()
      */
-    QString wordCharacters() const {
-        return _wordCharacters;
-    }
+    QString wordCharacters() const { return _wordCharacters; }
 
     /**
      * Sets the type of effect used to alert the user when a 'bell' occurs in the
@@ -331,30 +318,34 @@ public:
     /**
      * Returns the type of effect used to alert the user when a 'bell' occurs in
      * the terminal session.
-     *
+     * 
      * See setBellMode()
      */
-    int bellMode() const;
+    int bellMode() const { return _bellMode; }
+
+    /**
+     * This enum describes the different types of sounds and visual effects which
+     * can be used to alert the user when a 'bell' occurs in the terminal
+     * session.
+     */
+    enum BellMode
+    {
+        /** A system beep. */
+        SystemBeepBell=0,
+        /**
+         * KDE notification.  This may play a sound, show a passive popup
+         * or perform some other action depending on the user's settings.
+         */
+        NotifyBell=1,
+        /** A silent, visual bell (eg. inverting the display's colors briefly) */
+        VisualBell=2,
+        /** No bell effects */
+        NoBell=3
+    };
 
     /** Play a visual bell for prompt or warning. */
     void visualBell();
 
-    /**
-     * Specified whether zoom terminal on Ctrl+mousewheel  is enabled or not.
-     * Defaults to enabled.
-     */
-    void setMouseWheelZoom(bool value) {
-        _mouseWheelZoom = value;
-    };
-    /**
-     * Returns the whether zoom terminal on Ctrl+mousewheel is enabled.
-     *
-     * See setMouseWheelZoom()
-     */
-    bool mouseWheelZoom() {
-        return _mouseWheelZoom;
-    };
-
     /**
      * Reimplemented.  Has no effect.  Use setVTFont() to change the font
      * used to draw characters in the display.
@@ -362,9 +353,7 @@ public:
     virtual void setFont(const QFont &);
 
     /** Returns the font used to draw characters in the display */
-    QFont getVTFont() {
-        return font();
-    }
+    QFont getVTFont() { return font(); }
 
     /**
      * Sets the font used to draw the display.  Has no effect if @p font
@@ -372,70 +361,48 @@ public:
      */
     void setVTFont(const QFont& font);
 
-    /** Increases the font size */
-    void increaseFontSize();
-
-    /** Decreases the font size */
-    void decreaseFontSize();
-
     /**
      * Specified whether anti-aliasing of text in the terminal display
      * is enabled or not.  Defaults to enabled.
      */
-    void setAntialias(bool value) {
-        _antialiasText = value;
-    }
+    void setAntialias( bool antialias ) { _antialiasText = antialias; }
     /**
      * Returns true if anti-aliasing of text in the terminal is enabled.
      */
-    bool antialias() const {
-        return _antialiasText;
-    }
+    bool antialias() const { return _antialiasText;   }
 
     /**
      * Specifies whether characters with intense colors should be rendered
      * as bold. Defaults to true.
      */
-    void setBoldIntense(bool value) {
-        _boldIntense = value;
-    }
+    void setBoldIntense(bool value) { _boldIntense = value; }
     /**
      * Returns true if characters with intense colors are rendered in bold.
      */
-    bool getBoldIntense() const {
-        return _boldIntense;
-    }
+    bool getBoldIntense() const { return _boldIntense; }
 
     /**
      * Sets whether or not the current height and width of the
      * terminal in lines and columns is displayed whilst the widget
      * is being resized.
      */
-    void setShowTerminalSizeHint(bool on) {
-        _showTerminalSizeHint = on;
-    }
+    void setShowTerminalSizeHint(bool on) { _showTerminalSizeHint=on; }
     /**
      * Returns whether or not the current height and width of
      * the terminal in lines and columns is displayed whilst the widget
      * is being resized.
      */
-    bool showTerminalSizeHint() const {
-        return _showTerminalSizeHint;
-    }
+    bool showTerminalSizeHint() const { return _showTerminalSizeHint; }
 
     /**
      * Sets the status of the BiDi rendering inside the terminal display.
      * Defaults to disabled.
      */
-    void setBidiEnabled(bool set) {
-        _bidiEnabled = set;
-    }
+    void setBidiEnabled(bool set) { _bidiEnabled=set; }
     /**
      * Returns the status of the BiDi rendering in this widget.
      */
-    bool isBidiEnabled() const {
-        return _bidiEnabled;
-    }
+    bool isBidiEnabled() const { return _bidiEnabled; }
 
     /**
      * Sets the terminal screen section which is displayed in this widget.
@@ -445,14 +412,13 @@ public:
      * In terms of the model-view paradigm, the ScreenWindow is the model which is rendered
      * by the TerminalDisplay.
      */
-    void setScreenWindow(ScreenWindow* window);
+    void setScreenWindow( ScreenWindow* window );
     /** Returns the terminal screen section which is displayed in this widget.  See setScreenWindow() */
     ScreenWindow* screenWindow() const;
 
-    // Select the current line.
-    void selectCurrentLine();
+    static void setXSelection(const QString& text);
 
-    void printContent(QPainter& painter, bool friendly);
+    static bool HAVE_TRANSPARENCY;
 
 public slots:
     /**
@@ -460,39 +426,31 @@ public slots:
      *
      * it's needed for proper handling scroll commands in the Vt102Emulation class
      */
-    void scrollScreenWindow(enum ScreenWindow::RelativeScrollMode mode , int amount);
+    void scrollScreenWindow( enum ScreenWindow::RelativeScrollMode mode , int amount );
 
     /**
      * Causes the terminal display to fetch the latest character image from the associated
      * terminal screen ( see setScreenWindow() ) and redraw the display.
      */
-    void updateImage();
+    void updateImage(); 
     /**
      * Causes the terminal display to fetch the latest line status flags from the
      * associated terminal screen ( see setScreenWindow() ).
      */
     void updateLineProperties();
 
-    void setAutoCopySelectedText(bool enabled);
-
-    void setMiddleClickPasteMode(Enum::MiddleClickPasteModeEnum mode);
-
-    /** Copies the selected text to the X11 Selection. */
-    void copyToX11Selection();
-
-    /** Copies the selected text to the system clipboard. */
+    /** Copies the selected text to the clipboard. */
     void copyToClipboard();
-
     /**
      * Pastes the content of the clipboard into the
      * display.
      */
-    void pasteFromClipboard(bool appendEnter = false);
+    void pasteFromClipboard();
     /**
-     * Pastes the content of the X11 selection into the
+     * Pastes the content of the X selection into the
      * display.
      */
-    void pasteFromX11Selection(bool appendEnter = false);
+    void pasteFromXSelection();
 
     /**
        * Changes whether the flow control warning box should be shown when the flow control
@@ -503,9 +461,8 @@ public slots:
      * Returns true if the flow control warning box is enabled.
      * See outputSuspended() and setFlowControlWarningEnabled()
      */
-    bool flowControlWarningEnabled() const {
-        return _flowControlWarningEnabled;
-    }
+    bool flowControlWarningEnabled() const
+    { return _flowControlWarningEnabled; }
 
     /**
      * Causes the widget to display or hide a message informing the user that terminal
@@ -536,42 +493,28 @@ public slots:
     /** See setUsesMouse() */
     bool usesMouse() const;
 
-    void setBracketedPasteMode(bool bracketedPasteMode);
-    bool bracketedPasteMode() const;
-
     /**
      * Shows a notification that a bell event has occurred in the terminal.
      * TODO: More documentation here
      */
     void bell(const QString& message);
 
-    /**
-     * Gets the background of the display
-     * @see setBackgroundColor(), setColorTable(), setForegroundColor()
-     */
-    QColor getBackgroundColor() const;
-
     /**
      * Sets the background of the display to the specified color.
-     * @see setColorTable(), getBackgroundColor(), setForegroundColor()
+     * @see setColorTable(), setForegroundColor()
      */
     void setBackgroundColor(const QColor& color);
 
     /**
      * Sets the text of the display to the specified color.
-     * @see setColorTable(), setBackgroundColor(), getBackgroundColor()
+     * @see setColorTable(), setBackgroundColor()
      */
     void setForegroundColor(const QColor& color);
 
     /**
-     * Sets the display's contents margins.
+     * Called from the drag'n'drop popup. Causes the dropped URLs to be pasted as text.
      */
-    void setMargin(int margin);
-
-    /**
-     * Sets whether the contents are centered between the margins.
-     */
-    void setCenterContents(bool enable);
+    void dropMenuPasteTriggered();
 
 signals:
 
@@ -608,34 +551,31 @@ signals:
      *
      * @p override is set to false by default and the shortcut will be triggered as normal.
      */
-    void overrideShortcutCheck(QKeyEvent* keyEvent, bool& override);
+    void overrideShortcutCheck(QKeyEvent* keyEvent,bool& override);
 
-    void sendStringToEmu(const char*);
+   void sendStringToEmu(const char*);
 
 protected:
-    virtual bool event(QEvent* event);
+    virtual bool event( QEvent* event);
 
-    virtual void paintEvent(QPaintEvent* event);
+    virtual void paintEvent( QPaintEvent* event);
 
     virtual void showEvent(QShowEvent* event);
     virtual void hideEvent(QHideEvent* event);
     virtual void resizeEvent(QResizeEvent* event);
 
-    virtual void contextMenuEvent(QContextMenuEvent* event);
-
-    virtual void fontChange(const QFont&);
+    virtual void fontChange(const QFont& );
     virtual void focusInEvent(QFocusEvent* event);
     virtual void focusOutEvent(QFocusEvent* event);
     virtual void keyPressEvent(QKeyEvent* event);
-    virtual void leaveEvent(QEvent* event);
     virtual void mouseDoubleClickEvent(QMouseEvent* event);
-    virtual void mousePressEvent(QMouseEvent* event);
-    virtual void mouseReleaseEvent(QMouseEvent* event);
-    virtual void mouseMoveEvent(QMouseEvent* event);
-    virtual void extendSelection(const QPoint& pos);
-    virtual void wheelEvent(QWheelEvent* event);
+    virtual void mousePressEvent( QMouseEvent* event);
+    virtual void mouseReleaseEvent( QMouseEvent* event);
+    virtual void mouseMoveEvent( QMouseEvent* event);
+    virtual void extendSelection( const QPoint& pos );
+    virtual void wheelEvent( QWheelEvent* event);
 
-    virtual bool focusNextPrevChild(bool next);
+    virtual bool focusNextPrevChild( bool next );
 
     // drag and drop
     virtual void dragEnterEvent(QDragEnterEvent* event);
@@ -644,9 +584,9 @@ protected:
     enum DragState { diNone, diPending, diDragging };
 
     struct DragInfo {
-        DragState       state;
-        QPoint          start;
-        QDrag*          dragObject;
+      DragState       state;
+      QPoint          start;
+      QDrag*          dragObject;
     } _dragInfo;
 
     // classifies the 'ch' into one of three categories
@@ -660,11 +600,10 @@ protected:
     void clearImage();
 
     void mouseTripleClickEvent(QMouseEvent* event);
-    void selectLine(QPoint pos, bool entireLine);
 
     // reimplemented
-    virtual void inputMethodEvent(QInputMethodEvent* event);
-    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
+    virtual void inputMethodEvent ( QInputMethodEvent* event );
+    virtual QVariant inputMethodQuery( Qt::InputMethodQuery query ) const;
 
 protected slots:
 
@@ -672,39 +611,27 @@ protected slots:
     void blinkTextEvent();
     void blinkCursorEvent();
 
+    //Re-enables bell noises and visuals.  Used to disable further bells for a short period of time
+    //after emitting the first in a sequence of bell events.
+    void enableBell();
+
 private slots:
 
-    void unmaskBell();
-    void swapFGBGColors();
+    void swapColorTable();
     void tripleClickTimeout();  // resets possibleTripleClick
-    void viewScrolledByUser();
-
-    /**
-     * Called from the drag-and-drop popup. Causes the dropped URLs to be pasted as text.
-     */
-    void dropMenuPasteActionTriggered();
-
-    void dropMenuCdActionTriggered();
-
-    void dismissOutputSuspendedMessage();
 
 private:
+
     // -- Drawing helpers --
 
     // divides the part of the display specified by 'rect' into
     // fragments according to their colors and styles and calls
-    // drawTextFragment() or drawPrinterFriendlyTextFragment()
-    // to draw the fragments
+    // drawTextFragment() to draw the fragments
     void drawContents(QPainter& painter, const QRect& rect);
-    // draw a transparent rectangle over the line of the current match
-    void drawCurrentResultRect(QPainter& painter);
     // draws a section of text, all the text in this section
     // has a common color and style
-    void drawTextFragment(QPainter& painter, const QRect& rect,
-                          const QString& text, const Character* style);
-
-    void drawPrinterFriendlyTextFragment(QPainter& painter, const QRect& rect,
-                                         const QString& text, const Character* style);
+    void drawTextFragment(QPainter& painter, const QRect& rect, 
+                          const QString& text, const Character* style); 
     // draws the background for a text fragment
     // if useOpacitySetting is true then the color's alpha value will be set to
     // the display's transparency (set with setOpacity()), otherwise the background
@@ -712,13 +639,13 @@ private:
     void drawBackground(QPainter& painter, const QRect& rect, const QColor& color,
                         bool useOpacitySetting);
     // draws the cursor character
-    void drawCursor(QPainter& painter, const QRect& rect , const QColor& foregroundColor,
-                    const QColor& backgroundColor , bool& invertColors);
+    void drawCursor(QPainter& painter, const QRect& rect , const QColor& foregroundColor, 
+                                       const QColor& backgroundColor , bool& invertColors);
     // draws the characters or line graphics in a text fragment
-    void drawCharacters(QPainter& painter, const QRect& rect,  const QString& text,
-                        const Character* style, bool invertCharacterColor);
+    void drawCharacters(QPainter& painter, const QRect& rect,  const QString& text, 
+                                           const Character* style, bool invertCharacterColor);
     // draws a string of line graphics
-    void drawLineCharString(QPainter& painter, int x, int y,
+    void drawLineCharString(QPainter& painter, int x, int y, 
                             const QString& str, const Character* attributes);
 
     // draws the preedit string for input methods
@@ -731,7 +658,7 @@ private:
 
     // maps a point on the widget to the position ( ie. line and column )
     // of the character at that point.
-    void getCharacterPosition(const QPoint& widgetPoint, int& line, int& column) const;
+    void getCharacterPosition(const QPoint& widgetPoint,int& line,int& column) const;
 
     // the area where the preedit string for input methods will be draw
     QRect preeditRect() const;
@@ -767,20 +694,13 @@ private:
 
     bool handleShortcutOverrideEvent(QKeyEvent* event);
 
-    void doPaste(QString text, bool appendReturn);
-
-    void processMidButtonClick(QMouseEvent* event);
-
-    QPoint findLineStart(const QPoint &pnt);
-    QPoint findLineEnd(const QPoint &pnt);
-    QPoint findWordStart(const QPoint &pnt);
-    QPoint findWordEnd(const QPoint &pnt);
+    void doPaste(bool useXselection,bool appendReturn);
 
     // the window onto the terminal screen which this display
     // is currently showing.
     QPointer<ScreenWindow> _screenWindow;
 
-    bool _bellMasked;
+    bool _allowBell;
 
     QGridLayout* _gridLayout;
 
@@ -797,16 +717,17 @@ private:
     int _columns;    // the number of columns that can be displayed in the widget
 
     int _usedLines;  // the number of lines that are actually being used, this will be less
-    // than 'lines' if the character image provided with setImage() is smaller
-    // than the maximum image size which can be displayed
+                    // than 'lines' if the character image provided with setImage() is smaller
+                    // than the maximum image size which can be displayed
 
     int _usedColumns; // the number of columns that are actually being used, this will be less
-    // than 'columns' if the character image provided with setImage() is smaller
-    // than the maximum image size which can be displayed
+                     // than 'columns' if the character image provided with setImage() is smaller
+                     // than the maximum image size which can be displayed
 
-    QRect _contentRect;
+    int _contentHeight;
+    int _contentWidth;
     Character* _image; // [lines][columns]
-    // only the area [usedLines][usedColumns] in the image contains valid data
+               // only the area [usedLines][usedColumns] in the image contains valid data
 
     int _imageSize;
     QVector<LineProperty> _lineProperties;
@@ -818,7 +739,6 @@ private:
     bool _showTerminalSizeHint;
     bool _bidiEnabled;
     bool _mouseMarks;
-    bool _bracketedPasteMode;
 
     QPoint  _iPntSel; // initial selection point
     QPoint  _pntSel; // current selection point
@@ -829,31 +749,27 @@ private:
     bool    _preserveLineBreaks;
     bool    _columnSelectionMode;
 
-    bool _autoCopySelectedText;
-    Enum::MiddleClickPasteModeEnum _middleClickPasteMode;
-
     QScrollBar* _scrollBar;
-    Enum::ScrollBarPositionEnum _scrollbarLocation;
-    bool _scrollFullPage;
+    ScrollBarPosition _scrollbarLocation;
     QString     _wordCharacters;
     int         _bellMode;
 
     bool _allowBlinkingText;  // allow text to blink
     bool _allowBlinkingCursor;  // allow cursor to blink
-    bool _textBlinking;   // text is blinking, hide it when drawing
-    bool _cursorBlinking;     // cursor is blinking, hide it when drawing
+    bool _textBlinking;   // hide text in paintEvent
+    bool _cursorBlinking;     // hide cursor in paintEvent
     bool _hasTextBlinker; // has characters to blink
     QTimer* _blinkTextTimer;
     QTimer* _blinkCursorTimer;
 
     bool _underlineLinks;     // Underline URL and hosts on mouse hover
-    bool _openLinksByDirectClick;     // Open URL and hosts by single mouse click
+    bool _isFixedSize; // columns/lines are locked.
 
-    bool _ctrlRequiredForDrag; // require Ctrl key for drag selected text
+    bool _ctrlDrag; // require Ctrl key for drag selected text
 
-    Enum::TripleClickModeEnum _tripleClickMode;
+    TripleClickMode _tripleClickMode;
     bool _possibleTripleClick;  // is set in mouseDoubleClickEvent and deleted
-    // after QApplication::doubleClickInterval() delay
+                               // after QApplication::doubleClickInterval() delay
 
     QLabel* _resizeWidget;
     QTimer* _resizeTimer;
@@ -862,10 +778,12 @@ private:
 
     //widgets related to the warning message that appears when the user presses Ctrl+S to suspend
     //terminal output - informing them what has happened and how to resume output
-    QLabel* _outputSuspendedLabel;
+    QLabel* _outputSuspendedLabel; 
 
     uint _lineSpacing;
 
+    bool _colorsInverted; // true during visual bell
+
     QSize _size;
 
     QRgb _blendColor;
@@ -877,56 +795,50 @@ private:
     TerminalImageFilterChain* _filterChain;
     QRegion _mouseOverHotspotArea;
 
-    Enum::CursorShapeEnum _cursorShape;
+    KeyboardCursorShape _cursorShape;
 
-    // cursor color. If it is invalid (by default) then the foreground
+    // custom cursor color.  if this is invalid then the foreground
     // color of the character under the cursor is used
-    QColor _cursorColor;
+    QColor _cursorColor;  
 
-    struct InputMethodData {
+
+    struct InputMethodData
+    {
         QString preeditString;
         QRect previousPreeditRect;
     };
     InputMethodData _inputMethodData;
 
-    bool _antialiasText;   // do we anti-alias or not
-
-    bool _printerFriendly; // are we currently painting to a printer in black/white mode
+    bool _antialiasText;   // do we antialias or not
 
     //the delay in milliseconds between redrawing blinking text
     static const int TEXT_BLINK_DELAY = 500;
-
-    //the duration of the size hint in milliseconds
-    static const int SIZE_HINT_DURATION = 1000;
+    static const int DEFAULT_LEFT_MARGIN = 1;
+    static const int DEFAULT_TOP_MARGIN = 1;
 
     SessionController* _sessionController;
 
-    bool _trimTrailingSpaces;   // trim trailing spaces in selected text
-    bool _mouseWheelZoom;   // enable mouse wheel zooming or not
-
-    int _margin;      // the contents margin
-    bool _centerContents;   // center the contents between margins
-
-    qreal _opacity;
-
-    friend class TerminalDisplayAccessible;
+public:
+    static void setTransparencyEnabled(bool enable)
+    {
+        HAVE_TRANSPARENCY = enable;
+    }
 };
 
 class AutoScrollHandler : public QObject
 {
-    Q_OBJECT
+Q_OBJECT
 
 public:
-    explicit AutoScrollHandler(QWidget* parent);
+    AutoScrollHandler(QWidget* parent);
 protected:
     virtual void timerEvent(QTimerEvent* event);
-    virtual bool eventFilter(QObject* watched, QEvent* event);
+    virtual bool eventFilter(QObject* watched,QEvent* event);
 private:
-    QWidget* widget() const {
-        return static_cast<QWidget*>(parent());
-    }
+    QWidget* widget() const { return static_cast<QWidget*>(parent()); }
     int _timerId;
 };
+
 }
 
 #endif // TERMINALDISPLAY_H
